@@ -1,9 +1,9 @@
 from .mystery import mystery
-from .ment_calc import ment_calc
-from .sqrt import sqrt
-from .quad import quad
 from .among_us import among_us
 from .bin_rep import bin_rep
+from .ment_calc import ment_calc
+from .sqrt import sqrt
+from .cbrt import cbrt
 from .gcd import gcd
 from .lcm import lcm
 from .sin import sin
@@ -25,6 +25,7 @@ from .coth import coth
 from .sech import sech
 from .csch import csch
 from .floor import floor
+from .ceil import ceil
 from .exp import exp
 from .factorial import factorial
 from .integrate import integrate
@@ -32,7 +33,9 @@ from .ln import ln
 from .log import log
 from .radians import radians
 from .degrees import degrees
-from .cbrt import cbrt
+from .quad import quad
 from .cubic import cubic
 from .quartic import quartic
+from .quintic import quintic
+from .derivative import derivative
 from .constants import *
\ No newline at end of file
