@@ -1,4 +1,7 @@
-def acos(x):
+def acos(x) -> float:
+    """
+    Return the arc cosine (measured in randians) of x.
+    """
     from .asin import asin
     from .constants import pi
     if -1 <= x <= 1:
