@@ -1,4 +1,7 @@
-def asin(x):
+def asin(x) -> float:
+    """
+    Return the arc sine (measured in radians) of x.
+    """
     from .integrate import integrate
     from .constants import pi
     if -1 <= x <= 1:
