@@ -1,4 +1,7 @@
-def atan(x):
+def atan(x) -> float:
+    """
+    Return the arc tangent (measured in radians) of x.
+    """
     from .integrate import integrate
     def integrand(t):
         return 1/(1+t**2)
