@@ -1,4 +1,7 @@
-def bin_rep(n):
+def bin_rep(n) -> str:
+    """
+    Return the binary representaion of n.
+    """
     from struct import pack
     binary_representation = pack(">d", n)
     binary_representation = "".join(f"{b:08b}" for b in binary_representation)
