@@ -1,4 +1,7 @@
-def cbrt(x):
+def cbrt(x) -> float | complex:
+    """
+    Return the cubic root of x.
+    """
     from .constants import pi
     from .sqrt import sqrt
     from .atan import atan
