@@ -1,4 +1,9 @@
-def cos(x, deg=False):
+def cos(x, deg=False) -> float | complex:
+    """
+    Return the cosine of x.
+
+    Measured in radians as defualt.
+    """
     from .constants import pi, e
     if deg:
         x = pi*(x/180)
