@@ -1,4 +1,7 @@
-def cubic(a,b,c,d):
+def cubic(a,b,c,d) -> list:
+    """
+    Return the solutions of the cubic equation (form of: ax³ + bx² + cx + d = 0).
+    """
     from .cbrt import cbrt
     from .sqrt import sqrt
     from .quad import quad
