@@ -1,4 +1,7 @@
-def factorial(x):
+def factorial(x) -> float:
+    """
+    Return the factorial of x where x ∉ {-1, -2, -3, ...}.
+    """
     from .exp import exp
     from .integrate import integrate
     if type(x) is not complex:
