@@ -1,4 +1,7 @@
-def quad(a,b,c):
+def quad(a,b,c) -> list:
+    """
+    Return the solutions of the quadratic equation (form of: ax² + bx + c = 0).
+    """
     from .sqrt import sqrt
     if a == 0:
         raise ValueError("value of 'a' must be different to 0.")
