@@ -1,4 +1,7 @@
-def quartic(a,b,c,d,e):
+def quartic(a,b,c,d,e) -> list:
+    """
+    Return the solutions of the quartic equation (form of: ax⁴ + bx³ + cx² + dx + e = 0).
+    """
     from .sqrt import sqrt
     from .cubic import cubic
     if a == 0:
