@@ -1,4 +1,9 @@
-def sin(x, deg=False):
+def sin(x, deg=False) -> float | complex:
+    """
+    Return the sine of x.
+
+    Measured in radians as defualt.
+    """
     from .constants import pi, e
     if deg:
         x = pi*(x/180)
