@@ -1,4 +1,9 @@
-def tan(x, deg=False):
+def tan(x, deg=False) -> float | complex:
+    """
+    Return the tangent of x.
+
+    Measured in radians as defualt.
+    """
     from .sin import sin
     from .cos import cos
     from .constants import pi
